@@ -104,8 +104,11 @@ class TranslatedFields(object):
     def __init__(self, meta=None, **fields):
         self.fields = fields
         self.meta = meta
+        self.name = None
 
     def contribute_to_class(self, cls, name):
+        self.name = name
+
         # Called from django.db.models.base.ModelBase.__new__
         translations_model = create_translations_model(cls, name, self.meta, **self.fields)
 
@@ -213,7 +216,7 @@ class TranslatableModel(models.Model):
         """
         Return the language codes of all translated variations.
         """
-        return self._translations_model.objects.filter(master=self).values_list('language_code', flat=True)
+        return self._translations_model.objects.filter(master=self).values_list('language_code', flat=True).order_by('language_code')
 
 
     def _get_translated_model(self, language_code=None, use_fallback=False, auto_create=False):
@@ -355,6 +358,10 @@ class TranslatedFieldsModelBase(ModelBase):
         if bases[0] == models.Model:
             return new_class
 
+        # No action in abstract models.
+        if new_class._meta.abstract or new_class._meta.proxy:
+            return new_class
+
         # Validate a manually configured class.
         shared_model = _validate_master(new_class)
 
